@@ -1,4 +1,5 @@
 import argparse
+import shlex
 import sys
 from pathlib import Path
 
@@ -225,7 +226,7 @@ if __name__ == "__main__":
     sys.tracebacklimit = 0
     while True:
         try:
-            command = input("Enter command: ").split()
+            command = shlex.split(input("Enter command: "))
             args = get_args(command)
             if args.dbname:
                 dbname = args.dbname
